@@ -1,2 +1,2 @@
-from qfunction.base import *
+from qfunction.fundamentals import *
 #from qfunction.quantum.quantum_circuit import QuantumCircuit
\ No newline at end of file
